Learn R Programming

astronomyengine (version 0.1.0)

astro_body_code: Get the integer code for a celestial body by name

Description

Returns the integer code corresponding to the given English name.

Usage

astro_body_code(name)

Value

If name is one of the listed strings (case-sensitive), the returned value is the corresponding integer code (see astro_body), otherwise it is -1.

Arguments

name

One of the following strings: Sun, Moon, Mercury, Venus, Earth, Mars, Jupiter, Saturn, Uranus, Neptune, Pluto, EMB, SSB.

Examples

Run this code
astro_body_code("Sun")
astro_body_code("Neptune")

Run the code above in your browser using DataLab