Learn R Programming

astronomyengine (version 0.1.0)

astro_combine_rotation: Combine two rotation matrices

Description

Given two rotation matrices, returns a combined rotation matrix that is equivalent to rotating based on the first matrix, followed by the second.

Usage

astro_combine_rotation(a, b)

Value

The combined rotation matrix

Arguments

a

The first rotation to apply

b

The second rotation to apply

Examples

Run this code
# Combine two identity matrices (result is also identity)
rot_a <- astro_identity_matrix()
rot_b <- astro_identity_matrix()
combined <- astro_combine_rotation(rot_a, rot_b)

Run the code above in your browser using DataLab