Learn R Programming

astronomyengine (version 0.1.0)

astro_identity_matrix: Create an identity rotation matrix

Description

Returns a rotation matrix that has no effect on orientation. This matrix can be the starting point for other operations, such as using a series of calls to astro_pivot() to create a custom rotation matrix.

Usage

astro_identity_matrix()

Arguments

Value

A list with components:

rot

A 3x3 rotation matrix

status

Status code (0 = success)

Examples

Run this code
# Create an identity matrix
id <- astro_identity_matrix()
id

Run the code above in your browser using DataLab