Learn R Programming

astronomyengine (version 0.1.0)

astro_inverse_rotation: Calculate the inverse of a rotation matrix

Description

Given a rotation matrix that performs some coordinate transform, this function returns the matrix that reverses that transform.

Usage

astro_inverse_rotation(rotation)

Value

A rotation matrix that performs the opposite transformation

Arguments

rotation

A rotation matrix (list with rot component) as returned by astro_identity_matrix() or other rotation functions

Examples

Run this code
# Create a rotation and invert it
rot <- astro_identity_matrix()
inv <- astro_inverse_rotation(rot)

Run the code above in your browser using DataLab