Learn R Programming

astronomyengine (version 0.1.0)

astro_rotation_ECL_EQD: Rotation Matrix from J2000 Ecliptic to Equatorial of-Date

Description

Calculates a rotation matrix from J2000 mean ecliptic (ECL) to equatorial of-date (EQD).

Usage

astro_rotation_ECL_EQD(time)

Value

A rotation matrix that converts ECL to EQD.

Arguments

time

A POSIXct object representing the date and time.

Details

This is one of the family of functions that returns a rotation matrix for converting from one orientation to another.

Source: ECL = ecliptic system, using equator at J2000 epoch.

Target: EQD = equatorial system, using equator of date.

Examples

Run this code
astro_rotation_ECL_EQD(Sys.time())

Run the code above in your browser using DataLab