Learn R Programming

astronomyengine (version 0.1.0)

astro_rotation_ECL_EQJ: Rotation Matrix from ECL to EQJ

Description

Calculates a rotation matrix from J2000 mean ecliptic (ECL) to J2000 mean equator (EQJ).

Usage

astro_rotation_ECL_EQJ()

Arguments

Value

A rotation matrix that converts ECL to EQJ.

Details

This is one of the family of functions that returns a rotation matrix for converting from one orientation to another.

Source: ECL = ecliptic system, using equator at J2000 epoch.

Target: EQJ = equatorial system, using equator at J2000 epoch.

Examples

Run this code
astro_rotation_ECL_EQJ()

Run the code above in your browser using DataLab