Learn R Programming

astronomyengine (version 0.1.0)

astro_rotation_ECT_EQD: Rotation Matrix from ECT to EQD

Description

Calculates a rotation matrix from true ecliptic of date (ECT) to equator of date (EQD).

Usage

astro_rotation_ECT_EQD(time)

Value

A rotation matrix that converts ECT to EQD.

Arguments

time

A POSIXct object representing the date and time of the ecliptic/equator conversion.

Details

This is one of the family of functions that returns a rotation matrix for converting from one orientation to another.

Source: ECT = true ecliptic of date.

Target: EQD = equator of date.

Examples

Run this code
astro_rotation_ECT_EQD(Sys.time())

Run the code above in your browser using DataLab