Learn R Programming

astronomyengine (version 0.1.0)

astro_rotation_ECT_EQJ: Rotation Matrix from ECT to EQJ

Description

Calculates a rotation matrix from true ecliptic of date (ECT) to J2000 mean equator (EQJ).

Usage

astro_rotation_ECT_EQJ(time)

Value

A rotation matrix that converts ECT to EQJ.

Arguments

time

A POSIXct object representing the date and time at which the Earth's ecliptic defines the source orientation.

Details

This is one of the family of functions that returns a rotation matrix for converting from one orientation to another.

Source: ECT = ecliptic system, using true equinox of the specified date/time.

Target: EQJ = equatorial system, using mean equator at J2000 epoch.

Examples

Run this code
astro_rotation_ECT_EQJ(Sys.time())

Run the code above in your browser using DataLab