Learn R Programming

astronomyengine (version 0.1.0)

astro_rotation_EQD_ECL: Rotation Matrix from Equatorial of-Date to J2000 Ecliptic

Description

Calculates a rotation matrix from equatorial of-date (EQD) to J2000 mean ecliptic (ECL).

Usage

astro_rotation_EQD_ECL(time)

Value

A rotation matrix that converts EQD to ECL.

Arguments

time

A POSIXct object representing the date and time.

Details

This is one of the family of functions that returns a rotation matrix for converting from one orientation to another.

Source: EQD = equatorial system, using equator of date.

Target: ECL = ecliptic system, using equator at J2000 epoch.

Examples

Run this code
astro_rotation_EQD_ECL(Sys.time())

Run the code above in your browser using DataLab