Learn R Programming

astronomyengine (version 0.1.0)

astro_rotation_EQD_ECT: Rotation Matrix from EQD to ECT

Description

Calculates a rotation matrix from equator of date (EQD) to true ecliptic of date (ECT).

Usage

astro_rotation_EQD_ECT(time)

Value

A rotation matrix that converts EQD to ECT.

Arguments

time

A POSIXct object representing the date and time of the equator/ecliptic conversion.

Details

This is one of the family of functions that returns a rotation matrix for converting from one orientation to another.

Source: EQD = equator of date.

Target: ECT = true ecliptic of date.

Examples

Run this code
astro_rotation_EQD_ECT(Sys.time())

Run the code above in your browser using DataLab