Learn R Programming

astronomyengine (version 0.1.0)

astro_rotation_EQJ_ECL: Rotation Matrix from EQJ to ECL

Description

Calculates a rotation matrix from J2000 mean equator (EQJ) to J2000 mean ecliptic (ECL).

Usage

astro_rotation_EQJ_ECL(time_posix)

Value

A rotation matrix that converts EQJ to ECL at the specified time.

Arguments

time_posix

A POSIXct object specifying the date and time at which the Earth's equator defines the target orientation.

Details

This is one of the family of functions that returns a rotation matrix for converting from one orientation to another.

Source: EQJ = equatorial system, using equator at J2000 epoch.

Target: ECL = ecliptic system, using equator at J2000 epoch.

Examples

Run this code
time <- as.POSIXct("2024-01-01", tz = "UTC")
astro_rotation_EQJ_ECL(time)

Run the code above in your browser using DataLab