Learn R Programming

astronomyengine (version 0.1.0)

astro_rotation_EQJ_ECT: Rotation Matrix from EQJ to ECT

Description

Calculates a rotation matrix from J2000 mean equator (EQJ) to true ecliptic of date (ECT).

Usage

astro_rotation_EQJ_ECT(time_posix)

Value

A rotation matrix that converts EQJ to ECT at the specified time.

Arguments

time_posix

A POSIXct object specifying the date and time at which the Earth's equator defines the target orientation.

Details

This is one of the family of functions that returns a rotation matrix for converting from one orientation to another.

Source: EQJ = equatorial system, using mean equator at J2000 epoch.

Target: ECT = ecliptic system, using true equinox of the specified date/time.

Examples

Run this code
time <- as.POSIXct("2024-01-01", tz = "UTC")
astro_rotation_EQJ_ECT(time)

Run the code above in your browser using DataLab