Learn R Programming

astronomyengine (version 0.1.0)

astro_rotation_EQJ_EQD: Rotation Matrix from EQJ to EQD

Description

Calculates a rotation matrix from J2000 mean equator (EQJ) to equatorial of-date (EQD).

Usage

astro_rotation_EQJ_EQD(time_posix)

Value

A rotation matrix that converts EQJ to EQD at the specified time.

Arguments

time_posix

A POSIXct object specifying the date and time at which the Earth's equator defines the target orientation.

Details

This is one of the family of functions that returns a rotation matrix for converting from one orientation to another.

Source: EQJ = equatorial system, using equator at J2000 epoch.

Target: EQD = equatorial system, using equator of the specified date/time.

Examples

Run this code
time <- as.POSIXct("2024-01-01", tz = "UTC")
astro_rotation_EQJ_EQD(time)

Run the code above in your browser using DataLab