Learn R Programming

astronomyengine (version 0.1.0)

astro_rotation_EQJ_GAL: Rotation Matrix from EQJ to GAL

Description

Calculates a rotation matrix from J2000 mean equator (EQJ) to galactic (GAL).

Usage

astro_rotation_EQJ_GAL()

Arguments

Value

A rotation matrix that converts EQJ to GAL.

Details

This is one of the family of functions that returns a rotation matrix for converting from one orientation to another.

Source: EQJ = equatorial system, using the equator at the J2000 epoch.

Target: GAL = galactic system (IAU 1958 definition).

Examples

Run this code
astro_rotation_EQJ_GAL()

Run the code above in your browser using DataLab