Learn R Programming

astronomyengine (version 0.1.0)

astro_rotation_EQJ_HOR: Rotation Matrix from J2000 Equatorial to Horizontal

Description

Calculates a rotation matrix from J2000 mean equator (EQJ) to horizontal (HOR).

Usage

astro_rotation_EQJ_HOR(time, latitude, longitude, height)

Value

A rotation matrix that converts EQJ to HOR. The components represent: x = north, y = west, z = zenith (straight up from observer).

Arguments

time

A POSIXct object representing the date and time of observation.

latitude

The observer's geographic latitude in degrees.

longitude

The observer's geographic longitude in degrees.

height

The observer's elevation above sea level in meters.

Details

This is one of the family of functions that returns a rotation matrix for converting from one orientation to another.

Source: EQJ = equatorial system, using the equator at J2000 epoch.

Target: HOR = horizontal system (x=North, y=West, z=Zenith).

Examples

Run this code
astro_rotation_EQJ_HOR(Sys.time(), latitude = -35.28, longitude = 149.12, height = 0)

Run the code above in your browser using DataLab