Learn R Programming

astronomyengine (version 0.1.0)

astro_rotation_GAL_EQJ: Rotation Matrix from GAL to EQJ

Description

Calculates a rotation matrix from galactic (GAL) to J2000 mean equator (EQJ).

Usage

astro_rotation_GAL_EQJ()

Arguments

Value

A rotation matrix that converts GAL to EQJ.

Details

This is one of the family of functions that returns a rotation matrix for converting from one orientation to another.

Source: GAL = galactic system (IAU 1958 definition).

Target: EQJ = equatorial system, using the equator at the J2000 epoch.

Examples

Run this code
astro_rotation_GAL_EQJ()

Run the code above in your browser using DataLab