Learn R Programming

astronomyengine (version 0.1.0)

astro_rotation_HOR_EQD: Rotation Matrix from HOR to EQD

Description

Calculates a rotation matrix from horizontal (HOR) to equatorial of-date (EQD).

Usage

astro_rotation_HOR_EQD(time, latitude, longitude, height)

Value

A rotation matrix that converts HOR to EQD.

Arguments

time

A POSIXct object representing the date and time at which the Earth's equator applies.

latitude

The observer's geographic latitude in degrees.

longitude

The observer's geographic longitude in degrees.

height

The observer's elevation above sea level in meters.

Details

This is one of the family of functions that returns a rotation matrix for converting from one orientation to another.

Source: HOR = horizontal system (x = north, y = west, z = zenith).

Target: EQD = equatorial system, using equator of the specified date/time.

Examples

Run this code
astro_rotation_HOR_EQD(Sys.time(), latitude = -35.28, longitude = 149.12, height = 0)

Run the code above in your browser using DataLab