Learn R Programming

astronomyengine (version 0.1.0)

astro_rotation_HOR_EQJ: Rotation Matrix from Horizontal to J2000 Equatorial

Description

Calculates a rotation matrix from horizontal (HOR) to J2000 mean equator (EQJ).

Usage

astro_rotation_HOR_EQJ(time, latitude, longitude, height)

Value

A rotation matrix that converts HOR to EQJ at time and for the observer.

Arguments

time

A POSIXct object representing the date and time of observation.

latitude

The observer's geographic latitude in degrees.

longitude

The observer's geographic longitude in degrees.

height

The observer's elevation above sea level in meters.

Details

This is one of the family of functions that returns a rotation matrix for converting from one orientation to another.

Source: HOR = horizontal system (x=North, y=West, z=Zenith).

Target: EQJ = equatorial system, using equator at J2000 epoch.

Examples

Run this code
astro_rotation_HOR_EQJ(Sys.time(), latitude = -35.28, longitude = 149.12, height = 0)

Run the code above in your browser using DataLab