Learn R Programming

astronomyengine (version 0.1.0)

astro_search_lunar_eclipse: Search for a lunar eclipse

Description

Searches for the first lunar eclipse that occurs after the given start time. A lunar eclipse may be penumbral, partial, or total.

Usage

astro_search_lunar_eclipse(start_time)

Value

A list with the following elements:

kind

Integer code for eclipse type (0=penumbral, 1=partial, 2=total).

obscuration

Fraction of Moon's disc covered by Earth's umbra (0-1).

peak

POSIXct time of eclipse peak.

sd_total

Semi-duration of total phase in minutes.

sd_partial

Semi-duration of partial phase in minutes.

sd_penum

Semi-duration of penumbral phase in minutes.

Arguments

start_time

A POSIXct date and time for starting the search.

Examples

Run this code
start <- as.POSIXct("2025-01-01", tz = "UTC")
astro_search_lunar_eclipse(start)

Run the code above in your browser using DataLab