Learn R Programming

astronomyengine (version 0.1.0)

astronomyengine-package: astronomyengine: R Bindings to the 'Astronomy Engine' C Library

Description

Provides access to the 'Astronomy Engine' C library (https://github.com/cosinekitty/astronomy) by Don Cross. The library calculates positions of the Sun, Moon, and planets, and predicts astronomical events such as rise/set times, lunar phases, equinoxes, solstices, eclipses, and transits. It is based on the 'VSOP87' planetary model and is accurate to within approximately one arcminute. This package bundles the single-file C source so that other R packages can link against it via 'LinkingTo' without shipping their own copy.

Arguments

Author

Maintainer: Mitchell O'Hara-Wild mail@mitchelloharawild.com (ORCID)

Authors:

  • Don Cross (Author of the bundled Astronomy Engine C library) [copyright holder]

See Also