Learn R Programming

astronomyengine (version 0.1.0)

next_global_solar_eclipse: Search for the next global solar eclipse

Description

Finds the next solar eclipse in a series after the given eclipse time. Typically, you pass the peak value from a previous search_global_solar_eclipse or next_global_solar_eclipse call.

Usage

next_global_solar_eclipse(prev_eclipse_time)

Value

A list with the same structure as search_global_solar_eclipse.

Arguments

prev_eclipse_time

A POSIXct time near a previous eclipse peak.

Examples

Run this code
start <- as.POSIXct("2025-01-01", tz = "UTC")
eclipse1 <- search_global_solar_eclipse(start)
eclipse2 <- next_global_solar_eclipse(eclipse1$peak)

Run the code above in your browser using DataLab