powered by
Returns the integer code corresponding to the given English name.
astro_body_code(name)
If name is one of the listed strings (case-sensitive), the returned value is the corresponding integer code (see astro_body), otherwise it is -1.
name
-1
One of the following strings: Sun, Moon, Mercury, Venus, Earth, Mars, Jupiter, Saturn, Uranus, Neptune, Pluto, EMB, SSB.
astro_body_code("Sun") astro_body_code("Neptune")
Run the code above in your browser using DataLab