powered by
Given two rotation matrices, returns a combined rotation matrix that is equivalent to rotating based on the first matrix, followed by the second.
astro_combine_rotation(a, b)
The combined rotation matrix
The first rotation to apply
The second rotation to apply
# Combine two identity matrices (result is also identity) rot_a <- astro_identity_matrix() rot_b <- astro_identity_matrix() combined <- astro_combine_rotation(rot_a, rot_b)
Run the code above in your browser using DataLab