powered by
Given a rotation matrix that performs some coordinate transform, this function returns the matrix that reverses that transform.
astro_inverse_rotation(rotation)
A rotation matrix that performs the opposite transformation
A rotation matrix (list with rot component) as returned by astro_identity_matrix() or other rotation functions
rot
astro_identity_matrix()
# Create a rotation and invert it rot <- astro_identity_matrix() inv <- astro_inverse_rotation(rot)
Run the code above in your browser using DataLab