powered by
Calculates a rotation matrix from J2000 mean ecliptic (ECL) to equatorial of-date (EQD).
astro_rotation_ECL_EQD(time)
A rotation matrix that converts ECL to EQD.
A POSIXct object representing the date and time.
This is one of the family of functions that returns a rotation matrix for converting from one orientation to another.
Source: ECL = ecliptic system, using equator at J2000 epoch.
Target: EQD = equatorial system, using equator of date.
astro_rotation_ECL_EQD(Sys.time())
Run the code above in your browser using DataLab