powered by
Calculates a rotation matrix from J2000 mean ecliptic (ECL) to J2000 mean equator (EQJ).
astro_rotation_ECL_EQJ()
A rotation matrix that converts ECL to EQJ.
This is one of the family of functions that returns a rotation matrix for converting from one orientation to another.
Source: ECL = ecliptic system, using equator at J2000 epoch.
Target: EQJ = equatorial system, using equator at J2000 epoch.
Run the code above in your browser using DataLab