A rotation matrix that converts ECL to HOR. The components of the
horizontal vector are: x = north, y = west, z = zenith (straight up from
the observer).
Arguments
time
A POSIXct object representing the date and time of observation.
latitude
The observer's geographic latitude in degrees.
longitude
The observer's geographic longitude in degrees.
height
The observer's elevation above sea level in meters.
Details
This is one of the family of functions that returns a rotation matrix
for converting from one orientation to another.
Source: ECL = ecliptic system, using equator at J2000 epoch.
Target: HOR = horizontal system (x = north, y = west, z = zenith).