powered by
Calculates a rotation matrix from true ecliptic of date (ECT) to equator of date (EQD).
astro_rotation_ECT_EQD(time)
A rotation matrix that converts ECT to EQD.
A POSIXct object representing the date and time of the ecliptic/equator conversion.
This is one of the family of functions that returns a rotation matrix for converting from one orientation to another.
Source: ECT = true ecliptic of date.
Target: EQD = equator of date.
astro_rotation_ECT_EQD(Sys.time())
Run the code above in your browser using DataLab