powered by
Calculates a rotation matrix from equatorial of-date (EQD) to J2000 mean ecliptic (ECL).
astro_rotation_EQD_ECL(time)
A rotation matrix that converts EQD to ECL.
A POSIXct object representing the date and time.
This is one of the family of functions that returns a rotation matrix for converting from one orientation to another.
Source: EQD = equatorial system, using equator of date.
Target: ECL = ecliptic system, using equator at J2000 epoch.
astro_rotation_EQD_ECL(Sys.time())
Run the code above in your browser using DataLab