powered by
Calculates a rotation matrix from equator of date (EQD) to true ecliptic of date (ECT).
astro_rotation_EQD_ECT(time)
A rotation matrix that converts EQD to ECT.
A POSIXct object representing the date and time of the equator/ecliptic conversion.
This is one of the family of functions that returns a rotation matrix for converting from one orientation to another.
Source: EQD = equator of date.
Target: ECT = true ecliptic of date.
astro_rotation_EQD_ECT(Sys.time())
Run the code above in your browser using DataLab