A rotation matrix that converts EQD to HOR. The components of the horizontal
vector are: x = north, y = west, z = zenith (straight up from the observer).
Arguments
time
A POSIXct object representing the date and time at which the Earth's
equator applies.
latitude
The observer's geographic latitude in degrees.
longitude
The observer's geographic longitude in degrees.
height
The observer's elevation above sea level in meters.
Details
This is one of the family of functions that returns a rotation matrix
for converting from one orientation to another.
Source: EQD = equatorial system, using equator of the specified date/time.
Target: HOR = horizontal system (x = north, y = west, z = zenith).