powered by
Calculates a rotation matrix from J2000 mean equator (EQJ) to J2000 mean ecliptic (ECL).
astro_rotation_EQJ_ECL(time_posix)
A rotation matrix that converts EQJ to ECL at the specified time.
A POSIXct object specifying the date and time at which the Earth's equator defines the target orientation.
This is one of the family of functions that returns a rotation matrix for converting from one orientation to another.
Source: EQJ = equatorial system, using equator at J2000 epoch.
Target: ECL = ecliptic system, using equator at J2000 epoch.
time <- as.POSIXct("2024-01-01", tz = "UTC") astro_rotation_EQJ_ECL(time)
Run the code above in your browser using DataLab