powered by
Calculates a rotation matrix from J2000 mean equator (EQJ) to galactic (GAL).
astro_rotation_EQJ_GAL()
A rotation matrix that converts EQJ to GAL.
This is one of the family of functions that returns a rotation matrix for converting from one orientation to another.
Source: EQJ = equatorial system, using the equator at the J2000 epoch.
Target: GAL = galactic system (IAU 1958 definition).
Run the code above in your browser using DataLab