powered by
Calculates a rotation matrix from J2000 mean equator (EQJ) to horizontal (HOR).
astro_rotation_EQJ_HOR(time, latitude, longitude, height)
A rotation matrix that converts EQJ to HOR. The components represent: x = north, y = west, z = zenith (straight up from observer).
A POSIXct object representing the date and time of observation.
The observer's geographic latitude in degrees.
The observer's geographic longitude in degrees.
The observer's elevation above sea level in meters.
This is one of the family of functions that returns a rotation matrix for converting from one orientation to another.
Source: EQJ = equatorial system, using the equator at J2000 epoch.
Target: HOR = horizontal system (x=North, y=West, z=Zenith).
astro_rotation_EQJ_HOR(Sys.time(), latitude = -35.28, longitude = 149.12, height = 0)
Run the code above in your browser using DataLab