powered by
Calculates a rotation matrix from galactic (GAL) to J2000 mean equator (EQJ).
astro_rotation_GAL_EQJ()
A rotation matrix that converts GAL to EQJ.
This is one of the family of functions that returns a rotation matrix for converting from one orientation to another.
Source: GAL = galactic system (IAU 1958 definition).
Target: EQJ = equatorial system, using the equator at the J2000 epoch.
Run the code above in your browser using DataLab