powered by
Calculates a rotation matrix from horizontal (HOR) to J2000 mean ecliptic (ECL).
astro_rotation_HOR_ECL(time, latitude, longitude, height)
A rotation matrix that converts HOR to ECL.
A POSIXct object representing the date and time of observation.
The observer's geographic latitude in degrees.
The observer's geographic longitude in degrees.
The observer's elevation above sea level in meters.
This is one of the family of functions that returns a rotation matrix for converting from one orientation to another.
Source: HOR = horizontal system (x = north, y = west, z = zenith).
Target: ECL = ecliptic system, using equator at J2000 epoch.
astro_rotation_HOR_ECL(Sys.time(), latitude = -35.28, longitude = 149.12, height = 0)
Run the code above in your browser using DataLab