powered by
Searches for the first lunar eclipse that occurs after the given start time. A lunar eclipse may be penumbral, partial, or total.
astro_search_lunar_eclipse(start_time)
A list with the following elements:
Integer code for eclipse type (0=penumbral, 1=partial, 2=total).
Fraction of Moon's disc covered by Earth's umbra (0-1).
POSIXct time of eclipse peak.
Semi-duration of total phase in minutes.
Semi-duration of partial phase in minutes.
Semi-duration of penumbral phase in minutes.
A POSIXct date and time for starting the search.
POSIXct
start <- as.POSIXct("2025-01-01", tz = "UTC") astro_search_lunar_eclipse(start)
Run the code above in your browser using DataLab