POSIXct value indicating when the Sun reaches the target longitude.
Arguments
target_lon
Numeric. The desired ecliptic longitude in degrees,
relative to the true equinox of date. Must be in the range [0, 360).
Conventional values: 0 = March equinox, 90 = June solstice,
180 = September equinox, 270 = December solstice.
start_time
POSIXct. The date and time for starting the search.
limit_days
Numeric. The number of days to search forward from
start_time. Recommended range: 1 to 10 days.
Details
This function can be used to determine equinoxes and solstices. However,
for calculating all equinoxes and solstices for a calendar year,
astro_seasons() is usually more convenient and efficient.
The search is performed within the time window from start_time to
start_time + limit_days. It is recommended to keep the search window
smaller than 10 days when possible.