Learn R Programming

astronomyengine (version 0.1.0)

astro_sun_position: Sun's position in ecliptic coordinates

Description

Calculates the geocentric ecliptic coordinates of the Sun. The returned coordinates are based on the true equinox of date (the instantaneous intersection of the Earth's equatorial plane and the ecliptic plane at the given time).

Usage

astro_sun_position(time)

Value

A list containing:

elon

Ecliptic longitude in degrees.

elat

Ecliptic latitude in degrees.

vec

A list with Cartesian coordinates:

x

X-coordinate in AU.

y

Y-coordinate in AU.

z

Z-coordinate in AU.

t

Time as POSIXct.

Arguments

time

A POSIXct object representing the date and time.

Details

This function accounts for light travel time from the Sun and corrects for precession and nutation of the Earth's axis.

Examples

Run this code
time <- as.POSIXct("2025-03-20 09:00:00", tz = "UTC")
astro_sun_position(time)

Run the code above in your browser using DataLab