next_global_solar_eclipse: Search for the next global solar eclipse
Description
Finds the next solar eclipse in a series after the given eclipse time.
Typically, you pass the peak value from a previous
search_global_solar_eclipse or next_global_solar_eclipse call.
Usage
next_global_solar_eclipse(prev_eclipse_time)
Value
A list with the same structure as search_global_solar_eclipse.